@@ -158,42 +158,17 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "MULNUM_GET_FIELD_LONG",
     "MULNUM_GET_FIELD_FLOAT",
     "MULNUM_GET_FIELD_DOUBLE",
-    "CALL_METHOD_VOID",
-    "CALL_METHOD_BYTE",
-    "CALL_METHOD_SHORT",
-    "CALL_METHOD_INT",
-    "CALL_METHOD_LONG",
-    "CALL_METHOD_FLOAT",
-    "CALL_METHOD_DOUBLE",
-    "CALL_METHOD_OBJECT",
-    "CALL_METHOD_MULNUM_BYTE",
-    "CALL_METHOD_MULNUM_SHORT",
-    "CALL_METHOD_MULNUM_INT",
-    "CALL_METHOD_MULNUM_LONG",
-    "CALL_METHOD_MULNUM_FLOAT",
-    "CALL_METHOD_MULNUM_DOUBLE",
-    "CALL_CALLBACK_METHOD_VOID",
-    "CALL_CALLBACK_METHOD_BYTE",
-    "CALL_CALLBACK_METHOD_SHORT",
-    "CALL_CALLBACK_METHOD_INT",
-    "CALL_CALLBACK_METHOD_LONG",
-    "CALL_CALLBACK_METHOD_FLOAT",
-    "CALL_CALLBACK_METHOD_DOUBLE",
-    "CALL_CALLBACK_METHOD_OBJECT",
-    "CALL_CALLBACK_METHOD_MULNUM_BYTE",
-    "CALL_CALLBACK_METHOD_MULNUM_SHORT",
-    "CALL_CALLBACK_METHOD_MULNUM_INT",
-    "CALL_CALLBACK_METHOD_MULNUM_LONG",
-    "CALL_CALLBACK_METHOD_MULNUM_FLOAT",
-    "CALL_CALLBACK_METHOD_MULNUM_DOUBLE",
+    "CALL_CLASS_METHOD",
+    "CALL_INSTANCE_METHOD",
+    "CALL_CALLBACK_METHOD",
     "ADD_INT",
     "ADD_LONG",
     "ADD_FLOAT",
     "ADD_DOUBLE",
-    "METHODTRACT_INT",
-    "METHODTRACT_LONG",
-    "METHODTRACT_FLOAT",
-    "METHODTRACT_DOUBLE",
+    "SUBTRACT_INT",
+    "SUBTRACT_LONG",
+    "SUBTRACT_FLOAT",
+    "SUBTRACT_DOUBLE",
     "MULTIPLY_INT",
     "MULTIPLY_LONG",
     "MULTIPLY_FLOAT",
