@@ -18,7 +18,7 @@ Suppose the following C<SPVM/Foo.spvm> is placed on a module search path.
 
   # SPVM/Foo.spvm
   class Foo {
-    sub sum : int ($x1: int, $x2: int) {
+    static method sum : int ($x1: int, $x2: int) {
       return $x1 + $x2;
     }
   }
@@ -31,7 +31,7 @@ Suppose the following C<SPVM/Foo/Bar.spvm> is placed on a module search path.
 
   # SPVM/Foo/Bar.spvm
   class Foo::Bar {
-    sub sum : int ($x1: int, $x2: int) {
+    static method sum : int ($x1: int, $x2: int) {
       return $x1 + $x2;
     }
   }
@@ -58,7 +58,7 @@ The definition of C<Foo> module is the following.
 
   # SPVM/Foo.spvm
   class Foo {
-    sub sum : int ($x1: int, $x2: int) {
+    static method sum : int ($x1: int, $x2: int) {
       return $x1 + $x2;
     }
   }
@@ -87,11 +87,11 @@ The definition of C<Foo> module is the following.
 
   # SPVM/Foo.spvm
   class Foo {
-    sub new : Foo () {
+    static method new : Foo () {
       return new Foo;
     }
 
-    sub sum : int ($self: self, $x1: int, $x2: int) (
+    method sum : int ($x1: int, $x2: int) (
       return $x1 + $x2;
     }
   }
@@ -238,8 +238,8 @@ If the argument type in the SPVM Method definition was a Multi Numeric Type, the
 
   # SPVM Method definition
   class Foo {
-    sub call_complex_float : void ($z: Complex_2f);
-    sub call_complex_double : void ($z: Complex_2d);
+    static method call_complex_float : void ($z: Complex_2f);
+    static method call_complex_double : void ($z: Complex_2d);
   }
 
   # Call from Perl
@@ -252,12 +252,12 @@ If the argument type in the SPVM Method definition was a Numeric Reference Type,
 
   # SPVM Method definition
   class Foo {
-    sub call_byte_ref : void ($num: byte&);
-    sub call_short_ref : void ($num: short&);
-    sub call_int_ref : void ($num: int&);
-    sub call_long_ref : void ($num: long&);
-    sub call_float_ref : void ($num: float&);
-    sub call_double_ref : void ($num: double&);
+    static method call_byte_ref : void ($num: byte&);
+    static method call_short_ref : void ($num: short&);
+    static method call_int_ref : void ($num: int&);
+    static method call_long_ref : void ($num: long&);
+    static method call_float_ref : void ($num: float&);
+    static method call_double_ref : void ($num: double&);
   }
 
   # Call from Perl
